@@ -1,8 +1,10 @@
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
-import six
-from six.moves import tkinter as Tk
+from matplotlib.externals import six
+from matplotlib.externals.six.moves import tkinter as Tk
+
+import numpy as np
 
 from matplotlib.backends import _tkagg
 
@@ -13,15 +15,19 @@ def blit(photoimage, aggimage, bbox=None, colormode=1):
         bbox_array = bbox.__array__()
     else:
         bbox_array = None
+    data = np.asarray(aggimage)
     try:
-        tk.call("PyAggImagePhoto", photoimage, id(aggimage), colormode, id(bbox_array))
+        tk.call(
+            "PyAggImagePhoto", photoimage,
+            id(data), colormode, id(bbox_array))
     except Tk.TclError:
         try:
             try:
                 _tkagg.tkinit(tk.interpaddr(), 1)
             except AttributeError:
                 _tkagg.tkinit(id(tk), 0)
-            tk.call("PyAggImagePhoto", photoimage, id(aggimage), colormode, id(bbox_array))
+            tk.call("PyAggImagePhoto", photoimage,
+                    id(data), colormode, id(bbox_array))
         except (ImportError, AttributeError, Tk.TclError):
             raise
 
