@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.4
+#!/usr/local/bin/python3.6
 """
 An animated image
 """
@@ -8,19 +8,21 @@ import matplotlib.animation as animation
 
 fig = plt.figure()
 
+
 def f(x, y):
     return np.sin(x) + np.cos(y)
 
 x = np.linspace(0, 2 * np.pi, 120)
 y = np.linspace(0, 2 * np.pi, 100).reshape(-1, 1)
 
-im = plt.imshow(f(x, y), cmap=plt.get_cmap('jet'))
+im = plt.imshow(f(x, y), cmap=plt.get_cmap('viridis'), animated=True)
+
 
 def updatefig(*args):
-    global x,y
+    global x, y
     x += np.pi / 15.
     y += np.pi / 20.
-    im.set_array(f(x,y))
+    im.set_array(f(x, y))
     return im,
 
 ani = animation.FuncAnimation(fig, updatefig, interval=50, blit=True)
