@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.4
+#!/usr/local/bin/python3.6
 """
 An animated image
 """
@@ -8,6 +8,7 @@ import matplotlib.animation as animation
 
 fig = plt.figure()
 
+
 def f(x, y):
     return np.sin(x) + np.cos(y)
 
@@ -20,11 +21,11 @@ ims = []
 for i in range(60):
     x += np.pi / 15.
     y += np.pi / 20.
-    im = plt.imshow(f(x, y))
+    im = plt.imshow(f(x, y), cmap='viridis', animated=True)
     ims.append([im])
 
 ani = animation.ArtistAnimation(fig, ims, interval=50, blit=True,
-    repeat_delay=1000)
+                                repeat_delay=1000)
 
 #ani.save('dynamic_images.mp4')
 
