@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.4
+#!/usr/local/bin/python3.6
 
 import numpy as np
 from matplotlib.pyplot import figure, show, rc
@@ -9,8 +9,8 @@ rc('xtick', labelsize=15)
 rc('ytick', labelsize=15)
 
 # force square figure and square axes looks better for polar, IMO
-fig = figure(figsize=(8,8))
-ax = fig.add_axes([0.1, 0.1, 0.8, 0.8], polar=True, axisbg='#d5de9c')
+fig = figure(figsize=(8, 8))
+ax = fig.add_axes([0.1, 0.1, 0.8, 0.8], projection='polar', axisbg='#d5de9c')
 
 r = np.arange(0, 3.0, 0.01)
 theta = 2*np.pi*r
