@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.4
+#!/usr/local/bin/python3.6
 """
 pcolormesh uses a QuadMesh, a faster generalization of pcolor, but
 with some restrictions.
@@ -12,13 +12,13 @@ from matplotlib import cm, colors
 from numpy import ma
 
 n = 12
-x = np.linspace(-1.5,1.5,n)
-y = np.linspace(-1.5,1.5,n*2)
-X,Y = np.meshgrid(x,y);
+x = np.linspace(-1.5, 1.5, n)
+y = np.linspace(-1.5, 1.5, n*2)
+X, Y = np.meshgrid(x, y)
 Qx = np.cos(Y) - np.cos(X)
 Qz = np.sin(Y) + np.sin(X)
 Qx = (Qx + 1.1)
-Z = np.sqrt(X**2 + Y**2)/5;
+Z = np.sqrt(X**2 + Y**2)/5
 Z = (Z - Z.min()) / (Z.max() - Z.min())
 
 # The color array can include masked values:
@@ -28,7 +28,7 @@ Zm = ma.masked_where(np.fabs(Qz) < 0.5*np.amax(Qz), Z)
 fig = figure()
 ax = fig.add_subplot(121)
 ax.set_axis_bgcolor("#bdb76b")
-ax.pcolormesh(Qx,Qz,Z, shading='gouraud')
+ax.pcolormesh(Qx, Qz, Z, shading='gouraud')
 ax.set_title('Without masked values')
 
 ax = fig.add_subplot(122)
@@ -38,7 +38,7 @@ ax.set_axis_bgcolor("#bdb76b")
 #cmap.set_bad('r', 1.0)
 #ax.pcolormesh(Qx,Qz,Zm, cmap=cmap)
 #  Or use the default, which is transparent:
-col = ax.pcolormesh(Qx,Qz,Zm,shading='gouraud')
+col = ax.pcolormesh(Qx, Qz, Zm, shading='gouraud')
 ax.set_title('With masked values')
 
 
